[Pkg-owncloud-commits] [owncloud-client] 178/219: SyncEngine: Use proper start indicator, max unit64.

Sandro Knauß hefee-guest at moszumanska.debian.org
Sat Oct 11 14:43:24 UTC 2014


This is an automated email from the git hooks/post-receive script.

hefee-guest pushed a commit to branch master
in repository owncloud-client.

commit 06c48f58cc819eb5dd4b67e25dc27a14e74a9887
Author: Klaas Freitag <freitag at owncloud.com>
Date:   Tue Sep 30 12:29:24 2014 +0200

    SyncEngine: Use proper start indicator, max unit64.
    
    This avoids a warning.
---
 src/mirall/protocolwidget.cpp | 2 +-
 src/mirall/syncengine.cpp     | 2 +-
 2 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/mirall/protocolwidget.cpp b/src/mirall/protocolwidget.cpp
index d37098f..d44c8bc 100644
--- a/src/mirall/protocolwidget.cpp
+++ b/src/mirall/protocolwidget.cpp
@@ -262,7 +262,7 @@ void ProtocolWidget::computeResyncButtonEnabled()
 
 void ProtocolWidget::slotProgressInfo( const QString& folder, const Progress::Info& progress )
 {
-    if( progress._completedFileCount == -1 ) {
+    if( progress._completedFileCount == std::numeric_limits<quint64>::max() ) {
         // The sync is restarting, clean the old items
         cleanIgnoreItems(folder);
         computeResyncButtonEnabled();
diff --git a/src/mirall/syncengine.cpp b/src/mirall/syncengine.cpp
index 4da1b7e..93c8e7d 100644
--- a/src/mirall/syncengine.cpp
+++ b/src/mirall/syncengine.cpp
@@ -656,7 +656,7 @@ void SyncEngine::slotDiscoveryJobFinished(int discoveryResult)
 
     // To announce the beginning of the sync
     emit aboutToPropagate(_syncedItems);
-    _progressInfo._completedFileCount = -1; // indicate the start.
+    _progressInfo._completedFileCount = std::numeric_limits<quint64>::max(); // indicate the start with max
     emit transmissionProgress(_progressInfo);
     _progressInfo._completedFileCount = 0;
 

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-owncloud/owncloud-client.git



More information about the Pkg-owncloud-commits mailing list